@@ -4,11 +4,37 @@
 get_ARPA_Lombardia_AQ_data_1y <-
   function(ID_station = NULL, Year = 2019, Var_vec = NULL, by_sensor = 0, verbose = T) {
 
+    ### Registry
     Metadata <- AQ_metadata_reshape()
     Metadata <- Metadata %>%
       dplyr::select(-c(.data$Altitude,.data$Province,.data$City,
                        .data$DateStart,.data$DateStop,.data$Latitude,.data$Longitude,
                        .data$ARPA_zone,.data$ARPA_stat_type))
+
+    ### Files names (from ARPA database)
+    if (Year %in% 1996:2000) {
+      file_name <- "2000.csv"
+    }
+    if (Year %in% 2001:2004) {
+      file_name <- "2004.csv"
+    }
+    if (Year %in% 2005:2007) {
+      file_name <- "2007.csv"
+    }
+    if (Year %in% 2008:2010) {
+      file_name <- "2010.csv"
+    }
+    if (Year >= 2011) {
+      file_name <- paste0(Year,".csv")
+    }
+
+    ### Checks if ID_station is valid (in the list of active stations)
+    '%notin%' <- Negate('%in%')
+    if (!is.null(ID_station) & all(ID_station %notin% Metadata$IDStation)) {
+      stop("ID_station NOT in the list of active stations. Change ID_station or use ID_station = NULL",
+           call. = FALSE)
+    }
+
     if (!is.null(ID_station)) {
       Metadata <- Metadata %>%
         dplyr::filter(.data$IDStation %in% ID_station)
@@ -29,7 +55,8 @@ get_ARPA_Lombardia_AQ_data_1y <-
       if (verbose==T) {
         cat("Importing data: started at", as.character(Sys.time()), "\n")
       }
-      Aria <- tibble::tibble(data.table::fread(unzip(zip_file, files = paste0(Year,".csv"))))
+      # Opening file
+      Aria <- tibble::tibble(data.table::fread(unzip(zip_file, files = file_name)))
       if (verbose==T) {
         cat("Processing data: started at", as.character(Sys.time()), "\n")
       }
@@ -49,7 +76,7 @@ get_ARPA_Lombardia_AQ_data_1y <-
         dplyr::mutate(Date = lubridate::ymd_hms(.data$Date))
     }
 
-    file.remove(paste0(Year,".csv"))
+    file.remove(file_name)
 
     Aria <- dplyr::right_join(Aria,Metadata, by = "IDSensor")
 
